/*
 * Name:    mt_digital_input.c
 *
 * Purpose: Tcl interface to generic MX digital input functions.
 *
 * Author:  William Lavender
 *
 *---------------------------------------------------------------------------
 *
 * Copyright 2002 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include <stdio.h>

#include <tcl.h>
#include <itcl.h>

#include "mx_util.h"
#include "mx_record.h"
#include "mx_digital_input.h"
#include "mx_handle.h"
#include "mx_tcl.h"
#include "mx_tcl_private.h"

MX_EXPORT int
Mx_digital_input_read_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	Tcl_Obj *resultPtr;
	MX_RECORD *record;
	unsigned long value;
	mx_status_type mx_status;

	if ( objc != 2 ) {
		Tcl_WrongNumArgs( interp, 1, objv,
		"Usage: digital_input_read record_handle" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	/* Read the digital input value. */

	mx_status = mx_digital_input_read( record, &value );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	resultPtr = Tcl_GetObjResult( interp );
	Tcl_SetLongObj( resultPtr, (long) value );

	return TCL_OK;
}

