/*
 * Name:    mt_digital_output.c
 *
 * Purpose: Tcl interface to generic MX digital output functions.
 *
 * Author:  William Lavender
 *
 *---------------------------------------------------------------------------
 *
 * Copyright 2002 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include <stdio.h>

#include <tcl.h>
#include <itcl.h>

#include "mx_util.h"
#include "mx_record.h"
#include "mx_digital_output.h"
#include "mx_handle.h"
#include "mx_tcl.h"
#include "mx_tcl_private.h"

MX_EXPORT int
Mx_digital_output_read_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	Tcl_Obj *resultPtr;
	MX_RECORD *record;
	unsigned long value;
	mx_status_type mx_status;

	if ( objc != 2 ) {
		Tcl_WrongNumArgs( interp, 1, objv,
		"Usage: digital_output_read record_handle" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	/* Read the digital output value. */

	mx_status = mx_digital_output_read( record, &value );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	resultPtr = Tcl_GetObjResult( interp );
	Tcl_SetLongObj( resultPtr, (long) value );

	return TCL_OK;
}

MX_EXPORT int
Mx_digital_output_write_cmd( ClientData clientData, Tcl_Interp *interp,
			int objc, Tcl_Obj *CONST objv[] )
{
	const char fname[] = "Mx_digital_output_write_cmd()";

	MX_RECORD *record;
	int tcl_status;
	long value;
	mx_status_type mx_status;

	if ( objc != 3 ) {
		Tcl_WrongNumArgs( interp, 2, objv,
		"Usage: digital_output_write record_handle value" );
		return TCL_ERROR;
	}

	mx_status = mxtcl_get_record_from_object( &record, interp, objv[1] );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	tcl_status = Tcl_GetLongFromObj( interp, objv[2], &value );

	if ( tcl_status != TCL_OK )
		return mxtcl_object_parse_error(
				interp, objv[2], "long", fname );

	/* Write the value. */

	mx_status = mx_digital_output_write( record, (unsigned long) value );

	if ( mx_status.code != MXE_SUCCESS )
		return mxtcl_error( interp, mx_status );

	return TCL_OK;
}

