/* 
 * Modified from tkAppInit.c by William Lavender
 *
 *	Provides a default version of the Tcl_AppInit procedure for
 *	use in wish and similar Tk-based applications.
 *
 * Copyright (c) 1993 The Regents of the University of California.
 * Copyright (c) 1994 Sun Microsystems, Inc.
 *
 * See the file "license.terms" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 * SCCS: @(#) tkAppInit.c 1.22 96/05/29 09:47:08
 *
 *--------------------------------------------------------------------------
 *
 * Modifications are under the following copyright.
 *
 * Copyright 1999-2001 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include <math.h>

#ifdef BUILD_MXWISH
#include "tk.h"
#else
#include "tcl.h"
#endif

/* Include MX and MX Tcl header files. */

#include "mx_osdef.h"
#include "mx_record.h"
#include "mx_tcl.h"

#include "mxAppInit.h"

int Mx_AppInit( Tcl_Interp *interp );

/*
 * The following variable is a special hack that is needed in order for
 * Sun shared libraries to be used for Tcl.
 */

#if defined( OS_WIN32 )
extern int _matherr();
int *tclDummyMathPtr = (int *) _matherr;
#elif defined( OS_SOLARIS ) && defined( __GNUC__ )
extern int matherr(struct exception *);
int *tclDummyMathPtr = (int *) matherr;
#elif ! defined( OS_IRIX )
extern int matherr();
int *tclDummyMathPtr = (int *) matherr;
#endif

/*
 *----------------------------------------------------------------------
 *
 * main --
 *
 *	This is the main program for the application.
 *
 * Results:
 *	None: Tk_Main never returns here, so this procedure never
 *	returns either.
 *
 * Side effects:
 *	Whatever the application does.
 *
 *----------------------------------------------------------------------
 */

int
main( int argc, char **argv )
{

#ifdef BUILD_MXWISH
    Tk_Main(argc, argv, Mx_AppInit);
#else
    Tcl_Main(argc, argv, Mx_AppInit);
#endif

    return 0;			/* Needed only to prevent compiler warning. */
}

/*
 *----------------------------------------------------------------------
 *
 * Mx_AppInit --
 *
 *	This procedure performs application-specific initialization.
 *	Most applications, especially those that incorporate additional
 *	packages, will have their own version of this procedure.
 *
 * Results:
 *	Returns a standard Tcl completion code, and leaves an error
 *	message in interp->result if an error occurs.
 *
 * Side effects:
 *	Depends on the startup script.
 *
 *----------------------------------------------------------------------
 */

int
Mx_AppInit(Tcl_Interp *interp)
{
    if (Tcl_Init(interp) == TCL_ERROR) {
	return TCL_ERROR;
    }

#ifdef BUILD_MXWISH
    if (Tk_Init(interp) == TCL_ERROR) {
	return TCL_ERROR;
    }
    Tcl_StaticPackage(interp, "Tk", Tk_Init, Tk_SafeInit);
#endif

    /*
     * Call the init procedures for included packages.  Each call should
     * look like this:
     *
     * if (Mod_Init(interp) == TCL_ERROR) {
     *     return TCL_ERROR;
     * }
     *
     * where "Mod" is the name of the module.
     */
    if (Itcl_Init(interp) == TCL_ERROR) {
        return TCL_ERROR;
    }

#ifdef BUILD_MXWISH
    if (Itk_Init(interp) == TCL_ERROR) {
        return TCL_ERROR;
    }
#endif

    Tcl_StaticPackage(interp, "Itcl", Itcl_Init, Itcl_SafeInit);

#ifdef BUILD_MXWISH
    Tcl_StaticPackage(interp, "Itk", Itk_Init, (Tcl_PackageInitProc *) NULL);
#endif

    /*
     *  This is itkwish, so import all [incr Tcl] commands by
     *  default into the global namespace.  Fix up the autoloader
     *  to do the same.
     */

#ifdef BUILD_MXWISH
    if (Tcl_Import(interp, Tcl_GetGlobalNamespace(interp),
            "::itk::*", /* allowOverwrite */ 1) != TCL_OK) {
        return TCL_ERROR;
    }
#endif

    if (Tcl_Import(interp, Tcl_GetGlobalNamespace(interp),
            "::itcl::*", /* allowOverwrite */ 1) != TCL_OK) {
        return TCL_ERROR;
    }

    if (Tcl_Eval(interp, "auto_mkindex_parser::slavehook { _%@namespace import -force ::itcl::* ::itk::* }") != TCL_OK) {
        return TCL_ERROR;
    }

    /****************************************************
     *  Call the init procedure(s) for the MX Tcl package. *
     ****************************************************/

    if ( Mx_Init(interp) == TCL_ERROR ) {
        return TCL_ERROR;
    }

#ifdef BUILD_MXWISH
    if ( Mxtk_Init(interp) == TCL_ERROR ) {
	return TCL_ERROR;
    }
#endif

    Tcl_StaticPackage(interp, "Mx", Mx_Init, (Tcl_PackageInitProc *) NULL);

#ifdef BUILD_MXWISH
    Tcl_StaticPackage(interp, "Mx", Mxtk_Init, (Tcl_PackageInitProc *) NULL);
#endif

    /*
     * Specify a user-specific startup file to invoke if the application
     * is run interactively.  Typically the startup file is "~/.apprc"
     * where "app" is the name of the application.  If this line is deleted
     * then no user-specific startup file will be run under any conditions.
     */

#ifdef BUILD_MXWISH
    Tcl_SetVar(interp, "tcl_rcFileName", "~/.mxwishrc", TCL_GLOBAL_ONLY);
#else
    Tcl_SetVar(interp, "tcl_rcFileName", "~/.mxtclshrc", TCL_GLOBAL_ONLY);
#endif

    return TCL_OK;
}
