#
#  Copyright 1999-2002 Illinois Institute of Technology
#
#  See the file "LICENSE" for information on usage and redistribution
#  of this file, and for a DISCLAIMER OF ALL WARRANTIES.
#

package provide MxGui 0.60

proc mxgui_create_variable_widget { variable_record } {

	set variable_name [ $variable_record cget -name ]

	set variable_widget .variable_widget_
	append variable_widget $variable_name

# Setup the window and the title bar

	set status [ catch { toplevel $variable_widget } result ]

# If the window already exists, bring it to the top.

	if { $status != 0 } {
		raise $variable_widget
		focus $variable_widget
		return
	}

# Hide the window for now.

	wm withdraw $variable_widget

	wm title $variable_widget "Variable '$variable_name'"

##################################################################
#       Display the variable name at the top of the window       #
##################################################################

	frame $variable_widget.name_frame
	pack $variable_widget.name_frame -expand yes -fill x

	label $variable_widget.name_frame.name -text $variable_name \
				-background $MxGui::textbackground
	pack $variable_widget.name_frame.name

##################################################################
#                  Create the main control window                #
##################################################################

# Create a separator

	frame $variable_widget.sep1 -height 2 -borderwidth 1 -relief sunken
	pack $variable_widget.sep1 -expand yes -fill x

# Create the main window frame

	set main $variable_widget.main

	frame $main
	pack $main

	label $main.value_label -text "Old value: "
	label $main.value -text [ $variable_record receive_variable ]

	grid $main.value_label $main.value -sticky w

	label $main.new_value_label -text "New value: "

	iwidgets::entryfield $main.new_value -width 40

	grid $main.new_value_label $main.new_value -sticky w

	$main.new_value configure -command \
		[ code mxgui_set_variable $variable_widget $variable_record ]

	grid rowconfigure $main 0 -weight 1
	grid rowconfigure $main 1 -weight 1

####################################################################
# Add accept and dismiss buttons at the bottom of the window.      #
####################################################################

	frame $variable_widget.sep2 -height 2 -borderwidth 1 -relief sunken
	pack $variable_widget.sep2 -expand yes -fill x -pady 5

	set bottom $variable_widget.bottom_frame

	frame $bottom
	pack $bottom -side top

	button $bottom.accept -text Accept -command \
		[ code mxgui_set_variable $variable_widget $variable_record ]

	pack $bottom.accept -side left -padx 5

	button $bottom.dismiss -text Dismiss \
		-command [ code destroy $variable_widget ]

	pack $bottom.dismiss -side left -padx 5

	frame $variable_widget.sep3 -height 2 -borderwidth 1 
	pack $variable_widget.sep3 -expand yes -fill x -pady 2

# Make the window appear on the screen.

	wm deiconify $variable_widget
}

#
#  This procedure is called when the user requests a new variable value
#  by pressing the enter key in the entryfield widget.
#

proc mxgui_set_variable { variable_widget variable_record } {

	set variable_value [ $variable_widget.main.new_value get ]

	destroy $variable_widget

#  Get rid of any surrounding double quotes the user may have typed.

	set variable_value [ string trim $variable_value \" ]

#  Is this a string variable?  Need to compare the last six characters
#  in the record type to find out.

	set variable_type [ $variable_record get_field mx_type ]

	if { [ string last "string" $variable_type ] >= 0 } {

		#  Surround the string value with double quotes to protect
		#  any embedded spaces.

		set variable_value "\"$variable_value\""
	}

	$variable_record send_variable $variable_value
}

