#
#  Name:    mxscript_func.tcl
#
#  Purpose: This file contains utility functions used by the mxtclsh_script
#           and mxwish_script programs.
#
#  Author:  William Lavender
#
#--------------------------------------------------------------------------
#
#  Copyright 2001 Illinois Institute of Technology
#
#  See the file "LICENSE" for information on usage and redistribution
#  of this file, and a DISCLAIMER OF ALL WARRANTIES.
#

namespace eval MxScript {
	variable logfile_name
	variable mxdir
	variable scriptdir
	variable test
	variable use_gui
	variable user_script
}

proc MxScript::create_message_log_window {} {

	set window .message_log

        #
        #  Create the window.
        #

        iwidgets::scrolledtext $window -labeltext "Message Log"

        $window configure -visibleitems 40x10
        $window configure -hscrollmode dynamic
        $window configure -vscrollmode dynamic

        pack $window -expand yes -fill both

        #
        #  Install handlers to redirect the output of mx_info(), mx_error()
        #  and MX_DEBUG() to this window.
        #

        Mx::install_output_handlers $window

	#
	#  Install user interrupt and dialog handlers.  This is necessary
	#  since otherwise the program will block on tty input if run in
	#  the background.
	#

	Mx::install_user_interrupt_handler
	Mx::install_dialog_handler

}

proc MxScript::log_puts { message } {
	if { $MxScript::use_gui } {
		set textwindow [ .message_log childsite ]

		$textwindow configure -state normal

		.message_log insert end "$message\n"

		$textwindow configure -state disabled

		.message_log yview moveto 1.0

		update idletasks
	} else {
		puts $message
	}
}

proc MxScript::logfile_puts { message } {

	# Log file messages are only recorded if $MxScript::logfile_name
	# has a length greater than zero.

	if { $MxScript::logfile_name == "" } {
		return
	}

	#
	# Construct a timestamp to write to the log file.
	#

	set current_time [ clock seconds ]

	set timestamp [ clock format $current_time -format \
		"%d/%m/%Y %H:%M:%S " ]

	#
	# Finish by writing the message to the log file.
	#

	set logfile [ open $MxScript::logfile_name "a" ]

	puts $logfile "$timestamp $message"

	close $logfile

	return
}

